@@ -385,6 +385,7 @@
 
     this.setFromIdentity = function (identity) {
       var node, children, nl, reNl, nlNb, space, signature, previousIdentity;
+      var nl2, reNl2;
 
       if (identity && identity.full)
       {
@@ -399,6 +400,8 @@
         nl = '<br />';
         reNl = '<br ?/>(&nbsp;)?[ \n]?';
         space = '&nbsp;';
+        nl2 = '<br ?>';
+        reNl2 = '<br ?>(&nbsp;)?[ \n]?';
       } else {
         nl = '\n';
         reNl = '\n';
@@ -424,8 +427,9 @@
 
           if (currentIdentity.signature) {
             try {
-              var currentSignature = new RegExp('(' + reNl + '){' + nlNb + '}--' + space + reNl +
-                currentIdentity.signature.replace(/[-\[\]{}()*+?.,\\^$|#\s]/g, '\\$&'));
+              //var currentSignature = new RegExp('(' + reNl + '){' + nlNb + '}--' + space + reNl +
+              //  currentIdentity.signature.replace(/[-\[\]{}()*+?.,\\^$|#\s]/g, '\\$&'));
+              var currentSignature = new RegExp('(<p>)?(<br ?\/?>(&nbsp;)?[ \\n]?)?--&nbsp;<br ?\/?>(&nbsp;)?[ \\n]?(<\/p>)?' + currentIdentity.signature)
               if (vm.message.editable.text.search(currentSignature) >= 0) {
                 vm.message.editable.text = vm.message.editable.text.replace(currentSignature, signature);
                 return true;
